Merge branch '39-build-error-on-archlinux' into develop

This commit is contained in:
Deed 2018-06-15 22:14:01 +02:00
commit e9d91f7fc9
2 changed files with 17 additions and 4 deletions

View file

@ -556,11 +556,10 @@ Linux client archlinux build:
image: base/archlinux
script:
# Prepare environment
- pacman -Syyu --noconfirm pacman-contrib
- cp /etc/pacman.d/mirrorlist /etc/pacman.d/mirrorlist.backup
- curl -o /etc/pacman.d/mirrorlist.new https://www.archlinux.org/mirrorlist/all/
- sed -i 's/^#Server/Server/' /etc/pacman.d/mirrorlist.new
- ls /usr/bin/*
- pacman -Syyu --noconfirm pacman-contrib
- rankmirrors -n 6 /etc/pacman.d/mirrorlist.new > /etc/pacman.d/mirrorlist
- pacman -Syyu
- pacman -S --noconfirm
@ -618,6 +617,7 @@ Linux client archlinux build:
- yaourt -Syyu --noconfirm --aur boost-build
# Apply patch
- (for patchfile in $(cat patch/series); do if ! patch -Z -t -R -s -f --dry-run -p 1 -i patch/$patchfile; then patch -f -Z -t -p 1 -i patch/$patchfile || exit 2 ; fi;done)
- patch -f -Z -t -p 1 -i patch/02_archlinux_allocator_static_assert_error.patch
# Build
- mkdir -p luabind
- wget -q http://http.debian.net/debian/pool/main/l/luabind/luabind_0.9.1+dfsg.orig.tar.gz -O luabind.tar.gz
@ -625,7 +625,6 @@ Linux client archlinux build:
- tar xvf luabind.tar.gz -C luabind --strip 1 || exit 2
- tar xvf luabind-debian.tar.xz -C luabind || exit 2
- cd luabind
- ls -l
- for file in $(cat debian/patches/series); do patch -p1 < debian/patches/$file; done
- export -p DEB_HOST_MULTIARCH="/"; bjam -d2 release debug install cxxflags="-fPIC -Wno-deprecated -Wno-deprecated-declarations"
- export -p DEB_HOST_MULTIARCH="/"; bjam -d2 release debug install link=static cxxflags="-fPIC -Wno-deprecated -Wno-deprecated-declarations"
@ -640,7 +639,6 @@ Linux client archlinux build:
paths:
- code/build/bin
expire_in: 2 week
when: manual
# Gentoo Client

View file

@ -0,0 +1,15 @@
diff --git a/code/CMakeModules/nel.cmake b/code/CMakeModules/nel.cmake
index 95b28bb8a..92d014836 100644
--- a/code/CMakeModules/nel.cmake
+++ b/code/CMakeModules/nel.cmake
@@ -873,8 +873,8 @@ MACRO(NL_SETUP_BUILD)
ENDIF()
ENDIF()
- # use c++0x standard to use std::unique_ptr and std::shared_ptr
- SET(PLATFORM_CXXFLAGS "${PLATFORM_CXXFLAGS} -std=c++0x")
+ # use gnu++14 standard to use std::unique_ptr and std::shared_ptr
+ SET(PLATFORM_CXXFLAGS "${PLATFORM_CXXFLAGS} -std=gnu++14")
ADD_PLATFORM_FLAGS("-D_REENTRANT")